/**
 * The standard button to be used everywhere
 * */
export default {
  title: 'Components/Button',
  tags: ['autodocs'],
  argTypes: {
    buttonText: {
      control: 'text',
    },
    disabled: {
      control: 'boolean',
    },
    type: {
      control: 'select',
      options: ['Primary', 'Secondary', 'Tertiary'],
      mapping: {
        Primary: '',
        Secondary: 'rpf-button--secondary',
        Tertiary: 'rpf-button--tertiary',
        Danger: 'rpf-button--danger',
      },
    },
    variant: {
      control: 'select',
      options: ['Default', 'Danger'],
      mapping: {
        Default: '',
        Danger: 'rpf-button--danger',
      },
    },
    size: {
      control: 'select',
      options: ['Large', 'Small'],
      mapping: {
        Large: '',
        Small: 'rpf-button--sm',
      },
    },
    icon: {
      control: 'text',
      description: 'Icon names can be found [here](https://fonts.google.com/icons)',
    },
    iconPosition: {
      control: 'select',
      options: ['None', 'Left', 'Right'],
    },
    iconOnly: {
      control: 'boolean',
    },
    fullWidth: {
      control: 'boolean',
    },
  },
  args: {
    buttonText: 'Button text',
    disabled: false,
    type: 'Primary',
    size: 'Large',
    icon: 'sentiment_satisfied',
    iconPosition: 'None',
    iconOnly: false,
    fullWidth: false,
  },
}

const ButtonTemplate = ({ buttonText, disabled, fullWidth, iconPosition, iconOnly, icon, size, type, variant }) => {
  const className = [
    'rpf-button',
    type,
    variant,
    size,
    iconOnly && 'rpf-button--icon-only',
    fullWidth && 'rpf-button--full-width',
  ]
    .filter((n) => n)
    .join(' ')
  return `
  <button class="${className}"${disabled ? ' disabled' : ''}>
    ${
      (iconPosition === 'Left') | iconOnly
        ? '<span class="rpf-button__icon material-symbols-sharp">' + icon + '</span>'
        : ''
    }
    ${iconOnly ? '' : buttonText}
    ${
      iconPosition === 'Right' && !iconOnly
        ? '<span class="rpf-button__icon material-symbols-sharp">' + icon + '</span>'
        : ''
    }
  </button>`
}

export const Primary = ButtonTemplate.bind({})
Primary.args = {}

export const Secondary = ButtonTemplate.bind({})
Secondary.args = {
  type: 'Secondary',
}

export const Tertiary = ButtonTemplate.bind({})
Tertiary.args = {
  type: 'Tertiary',
}

export const Danger = ButtonTemplate.bind({})
Danger.args = {
  type: 'Danger',
}

export const Disabled = ButtonTemplate.bind({})
Disabled.args = {
  disabled: true,
}

export const Small = ButtonTemplate.bind({})
Small.args = {
  size: 'Small',
}

export const WithIcon = ButtonTemplate.bind({})
WithIcon.args = {
  iconPosition: 'On Left',
}

export const IconOnly = ButtonTemplate.bind({})
IconOnly.args = {
  iconOnly: true,
}

export const FullWidth = ButtonTemplate.bind({})
FullWidth.args = {
  fullWidth: true,
}

const LinkTemplate = ({ buttonText, disabled, icon, iconPosition, iconOnly, size, type }) => {
  const className = ['rpf-button', type, size, disabled ? 'rpf-button--disabled' : ''].filter((n) => n).join(' ')
  return `
  <a href="#" class="${className}">
  ${
    (iconPosition === 'Left') | iconOnly
      ? '<span class="rpf-button__icon material-symbols-sharp">' + icon + '</span>'
      : ''
  }
  ${iconOnly ? '' : buttonText}
  ${
    iconPosition === 'Right' && !iconOnly
      ? '<span class="rpf-button__icon material-symbols-sharp">' + icon + '</span>'
      : ''
  }
  </a>
  `
}

export const Link = LinkTemplate.bind({})
Link.args = {}

export const DisabledLink = LinkTemplate.bind({})
DisabledLink.args = {
  disabled: true,
}
